]> git.notmuchmail.org Git - notmuch/blobdiff - notmuch.c
notmuch show: Remove custom "unread" hack, (printing tag in two locations).
[notmuch] / notmuch.c
index 98c0bf377553b00cb8d3232e1bb5353bf3ab8d17..3b4cd6f13a40f5c586cd1f2e85e16e5ab833e29d 100644 (file)
--- a/notmuch.c
+++ b/notmuch.c
@@ -739,11 +739,11 @@ query_string_from_args (void *ctx, int argc, char *argv[])
  *
  * Examples include:
  *
*     5 minutes ago   (For times less than 60 minutes ago)
*     12:30           (For times >60 minutes but still today)
*     Yesterday
*     Monday          (Before yesterday but fewer than 7 days ago)
*     Oct. 12         (Between 7 and 180 days ago (about 6 months))
  *     2008-06-30      (More than 180 days ago)
  */
 #define MINUTE (60)
@@ -778,7 +778,7 @@ _format_relative_date (void *ctx, time_t then)
 
     if (delta < 3600) {
        snprintf (result, RELATIVE_DATE_MAX,
-                 "%d minutes ago", (int) (delta / 60));
+                 "%d mins. ago", (int) (delta / 60));
        return result;
     }
 
@@ -787,21 +787,23 @@ _format_relative_date (void *ctx, time_t then)
            delta < DAY)
        {
            strftime (result, RELATIVE_DATE_MAX,
-                     "%R", &tm_then); /* 12:30 */
+                     "Today %R", &tm_then); /* Today 12:30 */
            return result;
        } else if ((tm_now.tm_wday + 7 - tm_then.tm_wday) % 7 == 1) {
-           return "Yesterday";
+           strftime (result, RELATIVE_DATE_MAX,
+                     "Yest. %R", &tm_then); /* Yest. 12:30 */
+           return result;
        } else {
            if (tm_then.tm_wday != tm_now.tm_wday) {
                strftime (result, RELATIVE_DATE_MAX,
-                         "%A", &tm_then); /* Monday */
+                         "%a. %R", &tm_then); /* Mon. 12:30 */
                return result;
            }
        }
     }
 
     strftime (result, RELATIVE_DATE_MAX,
-             "%b %d", &tm_then); /* Oct. 12 */
+             "%B %d", &tm_then); /* October 12 */
     return result;
 }
 #undef MINUTE
@@ -848,7 +850,7 @@ search_command (void *ctx, int argc, char *argv[])
        date = notmuch_thread_get_oldest_date (thread);
        relative_date = _format_relative_date (local, date);
 
-       printf ("%s (%s) %s",
+       printf ("%s %12s %s",
                notmuch_thread_get_thread_id (thread),
                relative_date,
                notmuch_thread_get_subject (thread));
@@ -878,6 +880,32 @@ search_command (void *ctx, int argc, char *argv[])
     return ret;
 }
 
+static const char *
+_get_tags_as_string (void *ctx, notmuch_message_t *message)
+{
+    notmuch_tags_t *tags;
+    int first = 1;
+    const char *tag;
+    char *result;
+
+    result = talloc_strdup (ctx, "");
+    if (result == NULL)
+       return NULL;
+
+    for (tags = notmuch_message_get_tags (message);
+        notmuch_tags_has_more (tags);
+        notmuch_tags_advance (tags))
+    {
+       tag = notmuch_tags_get (tags);
+
+       result = talloc_asprintf_append (result, "%s%s",
+                                        first ? "" : " ", tag);
+       first = 0;
+    }
+
+    return result;
+}
+
 /* Get a nice, single-line summary of message. */
 static const char *
 _get_one_line_summary (void *ctx, notmuch_message_t *message)
@@ -886,6 +914,7 @@ _get_one_line_summary (void *ctx, notmuch_message_t *message)
     time_t date;
     const char *relative_date;
     const char *subject;
+    const char *tags;
 
     from = notmuch_message_get_header (message, "from");
 
@@ -894,8 +923,10 @@ _get_one_line_summary (void *ctx, notmuch_message_t *message)
 
     subject = notmuch_message_get_header (message, "subject");
 
-    return talloc_asprintf (ctx, "%s (%s) %s",
-                           from, relative_date, subject);
+    tags = _get_tags_as_string (ctx, message);
+
+    return talloc_asprintf (ctx, "%s (%s) %s (%s)",
+                           from, relative_date, subject, tags);
 }
 
 static void
@@ -950,18 +981,19 @@ show_message_part (GMimeObject *part, int *part_count)
        const char *filename = g_mime_part_get_filename (GMIME_PART (part));
        content_type = g_mime_object_get_content_type (GMIME_OBJECT (part));
 
-       printf ("%%attachment{ ID: %d, Content-type: %s, ",
+       printf ("\fattachment{ ID: %d, Content-type: %s\n",
                *part_count,
                g_mime_content_type_to_string (content_type));
-       printf ("Filename: %s ", filename);
-       printf ("%%attachment}\n");
+       printf ("Attachment: %s (%s)\n", filename,
+               g_mime_content_type_to_string (content_type));
+       printf ("\fattachment}\n");
 
        return;
     }
 
     content_type = g_mime_object_get_content_type (GMIME_OBJECT (part));
 
-    printf ("%%part{ ID: %d, Content-type: %s\n",
+    printf ("\fpart{ ID: %d, Content-type: %s\n",
            *part_count,
            g_mime_content_type_to_string (content_type));
 
@@ -975,8 +1007,13 @@ show_message_part (GMimeObject *part, int *part_count)
        if (wrapper)
            g_mime_data_wrapper_write_to_stream (wrapper, stream);
     }
+    else
+    {
+       printf ("Non-text part: %s\n",
+               g_mime_content_type_to_string (content_type));
+    }
 
-    printf ("%%part}\n");
+    printf ("\fpart}\n");
 
     g_object_unref (stream);
 }
@@ -1079,9 +1116,10 @@ show_command (void *ctx, unused (int argc), unused (char *argv[]))
     {
        message = notmuch_messages_get (messages);
 
-       printf ("%%message{\n");
+       printf ("\fmessage{ ID: %s\n",
+               notmuch_message_get_message_id (message));
 
-       printf ("%%header{\n");
+       printf ("\fheader{\n");
 
        printf ("%s\n", _get_one_line_summary (local, message));
 
@@ -1092,11 +1130,14 @@ show_command (void *ctx, unused (int argc), unused (char *argv[]))
                printf ("%s: %s\n", name, value);
        }
 
-       printf ("%%header}\n");
+       printf ("\fheader}\n");
+       printf ("\fbody{\n");
 
        show_message_body (notmuch_message_get_filename (message));
 
-       printf ("%%message}\n");
+       printf ("\fbody}\n");
+
+       printf ("\fmessage}\n");
 
        notmuch_message_destroy (message);
     }
@@ -739,11 +739,11 @@ query_string_from_args (void *ctx, int argc, char *argv[])
  * Examples include:
  *
- *     5 minutes ago   (For times less than 60 minutes ago)
- *     12:30           (For times >60 minutes but still today)
- *     Yesterday
- *     Monday          (Before yesterday but fewer than 7 days ago)
- *     Oct. 12         (Between 7 and 180 days ago (about 6 months))
+ *     5 mins. ago     (For times less than 60 minutes ago)
+ *     Today 12:30     (For times >60 minutes but still today)
+ *     Yest. 12:30
+ *     Mon.  12:30     (Before yesterday but fewer than 7 days ago)
+ *     October 12      (Between 7 and 180 days ago (about 6 months))
  *     2008-06-30      (More than 180 days ago)
  */